.. Copyright (C) 2015-2016 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2015-2016 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

The ``debops.ruby`` role can be used to configure a Ruby environment. The role
will install Ruby packages from the current OS release, as well as specified
Ruby gems, either system-wide or on a selected user account.
